@@ -5,20 +5,20 @@
  *	Created by:	Robert French
  *
  *	$Source: /cvsroot/gaim/gaim/src/protocols/zephyr/ZLocations.c,v $
- *	$Author: thekingant $
+ *	$Author: chipx86 $
  *
  *	Copyright (c) 1987,1988,1991 by the Massachusetts Institute of Technology.
  *	For copying and distribution information, see the file
  *	"mit-copyright.h". 
  */
-/* $Header: /cvsroot/gaim/gaim/src/protocols/zephyr/ZLocations.c,v 1.3 2003/11/11 07:08:13 thekingant Exp $ */
+/* $Header: /cvsroot/gaim/gaim/src/protocols/zephyr/ZLocations.c,v 1.4 2004/04/24 09:02:28 chipx86 Exp $ */
 
 #ifndef lint
 static char rcsid_ZLocations_c[] =
     "$Zephyr: /afs/athena.mit.edu/astaff/project/zephyr/src/lib/RCS/ZLocations.c,v 1.30 90/12/20 03:04:39 raeburn Exp $";
 #endif
 
-#include <internal.h>
+#include "internal.h"
 
 #include <pwd.h>
 
